@@ -1,7 +1,7 @@
 package App::dateseq;
 
-our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-26'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -62,6 +62,12 @@ _
         },
         date_format => {
             summary => 'strftime() format for each date',
+            description => <<'_',
+
+Default is `%Y-%m-%d`, unless when hour/minute/second is specified, then it is
+`%Y-%m-%dT%H:%M:%S`.
+
+_
             schema => ['str*'],
             cmdline_aliases => {f=>{}},
         },
@@ -110,13 +116,28 @@ sub dateseq {
 
     my %args = @_;
 
-    my $fmt  = $args{date_format} // '%Y-%m-%d';
+    $args{increment} //= DateTime::Duration->new(days=>1);
+
+    my $fmt  = $args{date_format} // do {
+        my $has_hms;
+        {
+            if ($args{from}->hour || $args{from}->minute || $args{from}->second) {
+                $has_hms++; last;
+            }
+            if (defined($args{to}) &&
+                    ($args{to}->hour || $args{to}->minute || $args{to}->second)) {
+                $has_hms++; last;
+            }
+            if ($args{increment}->hours || $args{increment}->minutes || $args{increment}->seconds) {
+                $has_hms++; last;
+            }
+        }
+        $has_hms ? '%Y-%m-%dT%H:%M:%S' : '%Y-%m-%d';
+    };
     my $strp = DateTime::Format::Strptime->new(
         pattern => $fmt,
     );
 
-    $args{increment} //= DateTime::Duration->new(days=>1);
-
     my $code_filter = sub {
         my $dt = shift;
         if ($args{business}) {
@@ -181,7 +202,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.05 of App::dateseq (from Perl distribution App-dateseq), released on 2015-09-25.
+This document describes version 0.06 of App::dateseq (from Perl distribution App-dateseq), released on 2015-09-26.
 
 =head1 FUNCTIONS
 
@@ -209,6 +230,9 @@ Only list business days (Mon-Sat).
 
 strftime() format for each date.
 
+Default is C<%Y-%m-%d>, unless when hour/minute/second is specified, then it is
+C<%Y-%m-%dT%H:%M:%S>.
+
 =item * B<from>* => I<date>
 
 Starting date.
